unit rOrders;

interface

uses
  System.SysUtils, System.Classes, frxClass, frxExportBaseDialog, frxExportPDF,
  Data.DB, DBAccess, Uni, UniProvider, MySQLUniProvider, System.IniFiles, Vcl.Forms,
  MemDS, frxDBSet, frxTableObject, frCoreClasses, Common.Logging, System.IOUtils;

type
  TrptOrders = class(TDataModule)
    frxOrders: TfrxReport;
    frxPDFExport1: TfrxPDFExport;
    ucKG: TUniConnection;
    uqOrders: TUniQuery;
    frxReportTableObject1: TfrxReportTableObject;
    frxDBOrders: TfrxDBDataset;
    procedure DataModuleCreate(Sender: TObject);

  private

  public
    procedure GenerateSimpleReport(OrderID: Integer);
    procedure PrepareReport(const SQL: string);
    procedure GeneratePDF;
  end;

var
  rptOrders: TrptOrders;

implementation

uses
  uLibrary;

{%CLASSGROUP 'Vcl.Controls.TControl'}

{$R *.dfm}

procedure TrptOrders.DataModuleCreate(Sender: TObject);
begin
  Logger.Log( 3, 'TAuthDatabase.DataModuleCreate' );
  LoadDatabaseSettings( ucKG, 'kgOrdersServer.ini' );
  try
    ucKG.Connect;
  except
    on E: Exception do
    begin
      Logger.Log(3, '--TrptOrders.DataModuleCreate -Error connecting to database: ' + E.Message);
    end;
  end;
end;

procedure TrptOrders.GenerateSimpleReport(OrderID: Integer);
begin
  try
    Logger.Log(5, 'Generating Report for Order ID: ' + OrderID.ToString);

    uqOrders.Close;
    uqOrders.SQL.Text := 'SELECT ORDER_ID FROM corrugated_plate_orders WHERE ORDER_ID = :OrderID';
    uqOrders.ParamByName('OrderID').AsInteger := OrderID;

    try
      uqOrders.Open;
    except
      on E: Exception do
      begin
        Logger.Log(1, 'Error executing query: ' + E.Message);
        Exit;
      end;
    end;

    frxOrders.PrepareReport;
    frxOrders.ShowReport;
  finally
    uqOrders.Close;
    frxOrders.Clear;
    Logger.Log(5, 'Report generation complete for Order ID: ' + OrderID.ToString);
  end;
end;


procedure TrptOrders.PrepareReport(const SQL: string);
begin
  // Prepare and load data into the query
  uqOrders.Close;
  uqOrders.SQL.Text := SQL;
  uqOrders.Open;
end;

procedure TrptOrders.GeneratePDF;
var
  ReportDir, ReportFileName: string;
begin
  ReportDir := 'C:\Projects\KGOrders\Reports';
  // Define output file
  ReportFileName := TPath.Combine(ReportDir, 'OrderReport_' + FormatDateTime('yyyymmdd_hhnnss', Now) + '.pdf');

  // Prepare and export the report
  frxOrders.PrepareReport;
  frxPDFExport1.FileName := ReportFileName;
  frxPDFExport1.ShowDialog := False;
  frxOrders.Export(frxPDFExport1);
  frxOrders.ShowPreparedReport;

  Logger.Log(5, 'PDF saved to: ' + ReportFileName);
end;


end.

